%global debug_package %{nil}

Name:       cuda-z
Version:    0.11.291
Release:    %mkrel 7
Summary:    Shows some basic information about CUDA-enabled GPUs and GPGPUs
Group:      Development/X11
License:    GPLv3
URL:        https://cuda-z.sourceforge.net/
# Get Source code from svn repository here: https://svn.code.sf.net/p/cuda-z/code/trunk using:
# - svn co https://svn.code.sf.net/p/cuda-z/code/trunk cuda-z-<major_version>.<svn_revision>
# - add log file using: svn log > ChangeLog
# - remove unneeded binaries from bld/bin
# - create tarball
Source0:    %{name}-%{version}.tar.xz
Patch0:     cuda-z-0.11.273-fixbuild.patch
Patch1:	    cuda-z-0.11.273-fix-host-defines-include.patch
Patch2:	    cuda-z-0.11.291-path-and-verbose.patch
Patch3:	    cuda-z-0.11.291-add-extra-arch.patch
# cuda 10.1 and beyond aren't able to compile with a reasonable (20GB) amount of RAM. Use
# this patch as a temporary workaround. Note that this patch decreases the
# result of the performance test due to un-optimization.
Patch4:	    cuda-z-0.11.273-enable-debug.patch
#
BuildRequires: qt5-devel
BuildRequires: nvidia-cuda-toolkit-devel
BuildRequires: imagemagick
BuildRequires: svn
Requires:      nvidia-cuda-toolkit
ExclusiveArch: x86_64

%description
CUDA-Z shows some basic information about CUDA-enabled GPUs and
GPGPUs. It works with nVIDIA Geforce, Quadro and Tesla cards, ION
chipsets.

CUDA-Z shows the following information:

    - Installed CUDA driver and dll version.
    - GPU core capabilities.
    - Integer and float point calculation performance.
    - Performance of double-precision operations if GPU is capable.
    - memory size and bandwidth.

This program also exports collected information to HTML format and
plain text file.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1 -b .path
%patch3 -p1 -b .arch
%patch4 -p1

%build
export NVCC_APPEND_FLAGS="-std c++14"
export CXXFLAGS="-std=c++14"
qmake-qt5
make

%install
mkdir -p %{buildroot}%{_bindir} \
   %{buildroot}%{_datadir}/icons/hicolor/{16x16,24x24,32x32,48x48,64x64,96x96,128x128,192x192,256x256}/apps

install -m 755 bin/cuda-z %{buildroot}/usr/bin
for i in 16x16 24x24 32x32 48x48 64x64 96x96 128x128 192x192 256x256; do
   convert res/img/icon.png %{buildroot}%{_datadir}/icons/hicolor/${i}/apps/cuda-z.png
done

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=CUDA-Z
GenericName=CUDA-Z
Comment=Shows infos about CUDA-enabled GPUs
Type=Application
Terminal=false
Icon=cuda-z
Categories=Development;DataVisualization;
Exec=cuda-z
EOF

desktop-file-install --dir %{buildroot}%{_datadir}/applications  %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%{_bindir}/cuda-z
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/cuda-z.png
%doc LICENSE.GPL3 ChangeLog


%changelog
* Fri Apr 28 2023 ghibo <ghibo> 0.11.291-7.mga9
+ Revision: 1955274
- Rebuild against CUDA 12.1.1

* Fri Mar 03 2023 ghibo <ghibo> 0.11.291-6.mga9.nonfree
+ Revision: 1946853
- Rebuild against CUDA 12.1.0

* Sat Dec 10 2022 ghibo <ghibo> 0.11.291-5.mga9.nonfree
+ Revision: 1920255
- Drop sm_35, sm_37 arch from build, as they are no longer supported in CUDA 12

* Tue Oct 04 2022 ghibo <ghibo> 0.11.291-4.mga9.nonfree
+ Revision: 1894806
- Rebuild against CUDA 11.8

* Sat Aug 20 2022 ghibo <ghibo> 0.11.291-3.mga9.nonfree
+ Revision: 1878919
- Force c++14
- Rebuild against CUDA 11.7.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Jan 02 2021 ghibo <ghibo> 0.11.291-1.mga8.nonfree
+ Revision: 1668259
- Update to release 0.11.291 from svn.
- Rework patches.
- Rebuilt against cuda-toolkit 11.2.
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon May 27 2019 ghibo <ghibo> 0.11.273-4.mga7.nonfree
+ Revision: 1399267
- Use a temporary workaround (drop performance with debug), to get compiling without running out of memory
- fix including of host_defines.h (deprecated).
- add sm_70, sm_72, sm_75 architectures.
- nvcc compilation more verbose.
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Thu Jul 06 2017 ghibo <ghibo> 0.11.273-1.mga6.nonfree
+ Revision: 1109106
- ExclusiveArch to x86_64 as CUDA is not available for x86
- imported package cuda-z


* Thu Jul 06 2017 ghibo <ghibo> 0.11.273-1.mga6
- Initial release.
- Add icons.
- Add patch for fix building.
